import type { PeerId } from '@libp2p/interface-peer-id';
import type { Startable } from '@libp2p/interfaces/startable';
import type { QueryFunc } from './types.js';
import type { QueryEvent, QueryOptions } from '@libp2p/interface-dht';
import type { Metrics } from '@libp2p/interface-metrics';
export interface CleanUpEvents {
    'cleanup': CustomEvent;
}
export interface QueryManagerInit {
    lan?: boolean;
    disjointPaths?: number;
    alpha?: number;
}
export interface QueryManagerComponents {
    peerId: PeerId;
    metrics?: Metrics;
}
/**
 * Keeps track of all running queries
 */
export declare class QueryManager implements Startable {
    private readonly components;
    private readonly lan;
    disjointPaths: number;
    private readonly alpha;
    private readonly controllers;
    private running;
    private queries;
    private metrics?;
    constructor(components: QueryManagerComponents, init: QueryManagerInit);
    isStarted(): boolean;
    /**
     * Starts the query manager
     */
    start(): Promise<void>;
    /**
     * Stops all queries
     */
    stop(): Promise<void>;
    run(key: Uint8Array, peers: PeerId[], queryFunc: QueryFunc, options?: QueryOptions): AsyncGenerator<QueryEvent>;
}
//# sourceMappingURL=manager.d.ts.map