import { Message } from './message-types.js';
import type { Sink } from 'it-stream-types';
import type { StreamMuxer, StreamMuxerInit } from '@libp2p/interface-stream-muxer';
import type { Stream } from '@libp2p/interface-connection';
import type { MplexInit } from './index.js';
import type { Uint8ArrayList } from 'uint8arraylist';
export interface MplexStream extends Stream {
    sourceReadableLength: () => number;
    sourcePush: (data: Uint8ArrayList) => void;
}
interface MplexStreamMuxerInit extends MplexInit, StreamMuxerInit {
}
export declare class MplexStreamMuxer implements StreamMuxer {
    protocol: string;
    sink: Sink<Uint8Array>;
    source: AsyncIterable<Uint8Array>;
    private _streamId;
    private readonly _streams;
    private readonly _init;
    private readonly _source;
    private readonly closeController;
    private readonly rateLimiter;
    constructor(init?: MplexStreamMuxerInit);
    /**
     * Returns a Map of streams and their ids
     */
    get streams(): Stream[];
    /**
     * Initiate a new stream with the given name. If no name is
     * provided, the id of the stream will be used.
     */
    newStream(name?: string): Stream;
    /**
     * Close or abort all tracked streams and stop the muxer
     */
    close(err?: Error | undefined): void;
    /**
     * Called whenever an inbound stream is created
     */
    _newReceiverStream(options: {
        id: number;
        name: string;
    }): MplexStream;
    _newStream(options: {
        id: number;
        name: string;
        type: 'initiator' | 'receiver';
        registry: Map<number, MplexStream>;
    }): MplexStream;
    /**
     * Creates a sink with an abortable source. Incoming messages will
     * also have their size restricted. All messages will be varint decoded.
     */
    _createSink(): Sink<Uint8Array>;
    /**
     * Creates a source that restricts outgoing message sizes
     * and varint encodes them
     */
    _createSource(): any;
    _handleIncoming(message: Message): Promise<void>;
}
export {};
//# sourceMappingURL=mplex.d.ts.map