import { EventEmitter } from '@libp2p/interfaces/events';
import type { PeerStore, AddressBook, KeyBook, MetadataBook, ProtoBook, PeerStoreEvents, PeerStoreInit, Peer, TagOptions } from '@libp2p/interface-peer-store';
import type { PeerId } from '@libp2p/interface-peer-id';
import type { Datastore } from 'interface-datastore';
export interface PersistentPeerStoreComponents {
    peerId: PeerId;
    datastore: Datastore;
}
/**
 * An implementation of PeerStore that stores data in a Datastore
 */
export declare class PersistentPeerStore extends EventEmitter<PeerStoreEvents> implements PeerStore {
    addressBook: AddressBook;
    keyBook: KeyBook;
    metadataBook: MetadataBook;
    protoBook: ProtoBook;
    private readonly components;
    private readonly store;
    constructor(components: PersistentPeerStoreComponents, init?: PeerStoreInit);
    forEach(fn: (peer: Peer) => void): Promise<void>;
    all(): Promise<Peer[]>;
    /**
     * Delete the information of the given peer in every book
     */
    delete(peerId: PeerId): Promise<void>;
    /**
     * Get the stored information of a given peer
     */
    get(peerId: PeerId): Promise<Peer>;
    /**
     * Returns true if we have a record of the peer
     */
    has(peerId: PeerId): Promise<boolean>;
    tagPeer(peerId: PeerId, tag: string, options?: TagOptions): Promise<void>;
    unTagPeer(peerId: PeerId, tag: string): Promise<void>;
    getTags(peerId: PeerId): Promise<Array<{
        name: string;
        value: number;
    }>>;
}
//# sourceMappingURL=index.d.ts.map