import type { DNSResolver } from './index.js';
/**
 * Browsers limit concurrent connections per host (~6), we don't want to exhaust
 * the limit so this value controls how many DNS queries can be in flight at
 * once.
 */
export declare const DEFAULT_QUERY_CONCURRENCY = 4;
export interface DNSOverHTTPSOptions {
    queryConcurrency?: number;
}
/**
 * Uses the RFC 1035 'application/dns-message' content-type to resolve DNS
 * queries.
 *
 * This resolver needs more dependencies than the non-standard
 * DNS-JSON-over-HTTPS resolver so can result in a larger bundle size and
 * consequently is not preferred for browser use.
 *
 * @see https://datatracker.ietf.org/doc/html/rfc1035
 * @see https://developers.cloudflare.com/1.1.1.1/encryption/dns-over-https/make-api-requests/dns-wireformat/
 * @see https://github.com/curl/curl/wiki/DNS-over-HTTPS#publicly-available-servers
 * @see https://dnsprivacy.org/public_resolvers/
 */
export declare function dnsOverHttps(url: string, init?: DNSOverHTTPSOptions): DNSResolver;
//# sourceMappingURL=dns-over-https.d.ts.map