/**
 * @packageDocumentation
 *
 * An implementation of a Multiaddr in JavaScript
 *
 * @example
 *
 * ```js
 * import { multiaddr } from '@multiformats/multiaddr'
 *
 * const ma = multiaddr('/ip4/127.0.0.1/tcp/1234')
 * ```
 */
import type { MultiaddrInput, Multiaddr as MultiaddrInterface, MultiaddrObject, Protocol, NodeAddress, ResolveOptions } from './index.js';
declare const inspect: unique symbol;
export declare const symbol: unique symbol;
/**
 * Creates a {@link Multiaddr} from a {@link MultiaddrInput}
 */
export declare class Multiaddr implements MultiaddrInterface {
    #private;
    bytes: Uint8Array;
    [symbol]: boolean;
    constructor(addr?: MultiaddrInput);
    toString(): string;
    toJSON(): string;
    toOptions(): MultiaddrObject;
    protos(): Protocol[];
    protoCodes(): number[];
    protoNames(): string[];
    tuples(): Array<[number, Uint8Array?]>;
    stringTuples(): Array<[number, string?]>;
    encapsulate(addr: MultiaddrInput): Multiaddr;
    decapsulate(addr: Multiaddr | string): Multiaddr;
    decapsulateCode(code: number): Multiaddr;
    getPeerId(): string | null;
    getPath(): string | null;
    equals(addr: {
        bytes: Uint8Array;
    }): boolean;
    resolve(options?: ResolveOptions): Promise<MultiaddrInterface[]>;
    nodeAddress(): NodeAddress;
    isThinWaistAddress(addr?: Multiaddr): boolean;
    /**
     * Returns Multiaddr as a human-readable string
     * https://nodejs.org/api/util.html#utilinspectcustom
     *
     * @example
     * ```js
     * import { multiaddr } from '@multiformats/multiaddr'
     *
     * console.info(multiaddr('/ip4/127.0.0.1/tcp/4001'))
     * // 'Multiaddr(/ip4/127.0.0.1/tcp/4001)'
     * ```
     */
    [inspect](): string;
}
export {};
//# sourceMappingURL=multiaddr.d.ts.map