/**
 * @typedef {import('../types').MultihashHasherLoader} MultihashHasherLoader
 */
export class BitswapMessage {
    /**
     * @param {boolean} full
     */
    constructor(full: boolean);
    full: boolean;
    /** @type {Map<string, Entry>} */
    wantlist: Map<string, Entry>;
    /** @type {Map<string, Uint8Array>} */
    blocks: Map<string, Uint8Array>;
    /** @type {Map<string, import('./message').Message.BlockPresenceType>} */
    blockPresences: Map<string, import('./message').Message.BlockPresenceType>;
    pendingBytes: number;
    get empty(): boolean;
    /**
     *
     * @param {CID} cid
     * @param {number} priority
     * @param {import('./message').Message.Wantlist.WantType | null} [wantType]
     * @param {boolean} [cancel]
     * @param {boolean} [sendDontHave]
     * @returns {void}
     */
    addEntry(cid: CID, priority: number, wantType?: Message.Wantlist.WantType | null | undefined, cancel?: boolean | undefined, sendDontHave?: boolean | undefined): void;
    /**
     * @param {CID} cid
     * @param {Uint8Array} block
     * @returns {void}
     */
    addBlock(cid: CID, block: Uint8Array): void;
    /**
     * @param {CID} cid
     */
    addHave(cid: CID): void;
    /**
     * @param {CID} cid
     */
    addDontHave(cid: CID): void;
    /**
     * @param {CID} cid
     */
    cancel(cid: CID): void;
    /**
     * @param {number} size
     */
    setPendingBytes(size: number): void;
    /**
     * Serializes to Bitswap Message protobuf of
     * version 1.0.0
     *
     * @returns {Uint8Array}
     */
    serializeToBitswap100(): Uint8Array;
    /**
     * Serializes to Bitswap Message protobuf of
     * version 1.1.0
     *
     * @returns {Uint8Array}
     */
    serializeToBitswap110(): Uint8Array;
    /**
     * @param {BitswapMessage} other
     * @returns {boolean}
     */
    equals(other: BitswapMessage): boolean;
    get [Symbol.toStringTag](): string;
}
export namespace BitswapMessage {
    /**
     * @param {Uint8Array} raw
     * @param {MultihashHasherLoader} [hashLoader]
     */
    export function deserialize(raw: Uint8Array, hashLoader?: import("../types").MultihashHasherLoader | undefined): Promise<BitswapMessage>;
    /**
     * @param {CID} cid
     */
    export function blockPresenceSize(cid: CID<any, number, number, import("multiformats/cid").Version>): number;
    export { Entry };
    export namespace WantType {
        const Block: Message.Wantlist.WantType;
        const Have: Message.Wantlist.WantType;
    }
    export namespace BlockPresenceType {
        const Have_1: Message.BlockPresenceType;
        export { Have_1 as Have };
        export const DontHave: Message.BlockPresenceType;
    }
}
export type MultihashHasherLoader = import('../types').MultihashHasherLoader;
import { BitswapMessageEntry as Entry } from "./entry.js";
import { CID } from "multiformats/cid";
import { Message } from "./message.js";
//# sourceMappingURL=index.d.ts.map