export class Notifications extends EventEmitter {
    /**
     * Internal module used to track events about incoming blocks,
     * wants and unwants.
     *
     * @param {PeerId} peerId
     */
    constructor(peerId: PeerId);
    _log: import("@libp2p/logger").Logger;
    /**
     * Signal the system that we received `block`.
     *
     * @param {CID} cid
     * @param {Uint8Array} block
     * @returns {void}
     */
    hasBlock(cid: CID, block: Uint8Array): void;
    /**
     * Signal the system that we are waiting to receive the
     * block associated with the given `cid`.
     * Returns a Promise that resolves to the block when it is received,
     * or undefined when the block is unwanted.
     *
     * @param {CID} cid
     * @param {object} [options]
     * @param {AbortSignal} [options.signal]
     * @returns {Promise<Uint8Array>}
     */
    wantBlock(cid: CID, options?: {
        signal?: AbortSignal | undefined;
    } | undefined): Promise<Uint8Array>;
    /**
     * Signal that the block is not wanted anymore.
     *
     * @param {CID} cid - the CID of the block that is not wanted anymore.
     * @returns {void}
     */
    unwantBlock(cid: CID): void;
}
export type CID = import('multiformats').CID;
export type PeerId = import('@libp2p/interface-peer-id').PeerId;
import { EventEmitter } from "events";
//# sourceMappingURL=notifications.d.ts.map