export class Stats extends EventEmitter {
    /**
     * @param {import('@libp2p/interface-libp2p').Libp2p} libp2p
     * @param {string[]} [initialCounters]
     * @param {object} _options
     * @param {boolean} _options.enabled
     * @param {number} _options.computeThrottleTimeout
     * @param {number} _options.computeThrottleMaxQueueSize
     */
    constructor(libp2p: import('@libp2p/interface-libp2p').Libp2p, initialCounters?: string[] | undefined, _options?: {
        enabled: boolean;
        computeThrottleTimeout: number;
        computeThrottleMaxQueueSize: number;
    });
    _initialCounters: string[];
    _options: {
        enabled: boolean;
        computeThrottleTimeout: number;
        computeThrottleMaxQueueSize: number;
        movingAverageIntervals: AverageIntervals;
    } & {
        enabled: boolean;
        computeThrottleTimeout: number;
        computeThrottleMaxQueueSize: number;
    };
    _enabled: boolean;
    _global: Stat;
    /** @type {Map<string, Stat>} */
    _peers: Map<string, Stat>;
    enable(): void;
    disable(): void;
    stop(): void;
    get snapshot(): Record<string, bigint>;
    get movingAverages(): Record<string, Record<number, import("@vascosantos/moving-average").IMovingAverage>>;
    /**
     * @param {PeerId|string} peerId
     * @returns {Stat|undefined}
     */
    forPeer(peerId: PeerId | string): Stat | undefined;
    /**
     *
     * @param {string|null} peer
     * @param {string} counter
     * @param {number} inc
     */
    push(peer: string | null, counter: string, inc: number): void;
    /**
     * @param {PeerId} peer
     */
    disconnected(peer: PeerId): void;
}
export type CID = import('multiformats').CID;
export type PeerId = import('@libp2p/interface-peer-id').PeerId;
export type AverageIntervals = [number, number, number];
import { EventEmitter } from "events";
import { Stat } from "./stat.js";
//# sourceMappingURL=index.d.ts.map