/**
 * @typedef {import('@libp2p/interface-peer-id').PeerId} PeerId
 * @typedef {import('multiformats').CID} CID
 */
export class WantManager {
    /**
     * @param {PeerId} peerId
     * @param {import('../network').Network} network
     * @param {import('../stats').Stats} stats
     * @param {import('@libp2p/interface-libp2p').Libp2p} libp2p
     */
    constructor(peerId: PeerId, network: import('../network').Network, stats: import('../stats').Stats, libp2p: import('@libp2p/interface-libp2p').Libp2p);
    /** @type {Map<string, MsgQueue>} */
    peers: Map<string, MsgQueue>;
    wantlist: Wantlist;
    network: import("../network").Network;
    _stats: import("../stats").Stats;
    _peerId: import("@libp2p/interface-peer-id").PeerId;
    _log: import("@libp2p/logger").Logger;
    /**
     * @private
     * @param {CID[]} cids
     * @param {boolean} cancel
     * @param {boolean} [force]
     */
    private _addEntries;
    /**
     * @private
     * @param {PeerId} peerId
     */
    private _startPeerHandler;
    /**
     * @private
     * @param {PeerId} peerId
     */
    private _stopPeerHandler;
    /**
     * add all the cids to the wantlist
     *
     * @param {CID[]} cids
     * @param {object} [options]
     * @param {AbortSignal} [options.signal]
     */
    wantBlocks(cids: CID[], options?: {
        signal?: AbortSignal | undefined;
    } | undefined): void;
    /**
     * Remove blocks of all the given keys without respecting refcounts
     *
     * @param {CID[]} cids
     */
    unwantBlocks(cids: CID[]): void;
    /**
     * Cancel wanting all of the given keys
     *
     * @param {CID[]} cids
     */
    cancelWants(cids: CID[]): void;
    /**
     * Returns a list of all currently connected peers
     */
    connectedPeers(): string[];
    /**
     * @param {PeerId} peerId
     */
    connected(peerId: PeerId): void;
    /**
     * @param {PeerId} peerId
     */
    disconnected(peerId: PeerId): void;
    start(): void;
    stop(): void;
}
export type PeerId = import('@libp2p/interface-peer-id').PeerId;
export type CID = import('multiformats').CID;
import { MsgQueue } from "./msg-queue.js";
import { Wantlist } from "../wantlist/index.js";
//# sourceMappingURL=index.d.ts.map