/**
 * @typedef {import('ipfs-unixfs-importer').ImporterOptions} ImporterOptions
 * @typedef {import('interface-blockstore').Blockstore} Blockstore
 * @typedef {import('multiformats/cid').CID} CID
 * @typedef {import('ipfs-unixfs').Mtime} Mtime
 *
 * @typedef {object} ImportResult
 * @property {CID} cid
 * @property {import('@ipld/dag-pb').PBNode} node
 * @property {number} size
 *
 * @typedef {object} DirContents
 * @property {CID} [cid]
 * @property {number} [size]
 *
 * @typedef {object} DirOptions
 * @property {Mtime} [mtime]
 * @property {number} [mode]
 * @property {import('multiformats/codecs/interface').BlockCodec<any, any>} [codec]
 * @property {import('multiformats/cid').Version} [cidVersion]
 * @property {boolean} [onlyHash]
 * @property {AbortSignal} [signal]
 */
/**
 * @typedef {object} DirProps
 * @property {boolean} root
 * @property {boolean} dir
 * @property {string} path
 * @property {boolean} dirty
 * @property {boolean} flat
 * @property {Dir} [parent]
 * @property {string} [parentKey]
 * @property {import('ipfs-unixfs').UnixFS} [unixfs]
 * @property {number} [mode]
 * @property {import('ipfs-unixfs').Mtime} [mtime]
 */
export class Dir {
    /**
     * @param {DirProps} props
     * @param {DirOptions} options
     */
    constructor(props: DirProps, options: DirOptions);
    options: DirOptions;
    root: boolean;
    dir: boolean;
    path: string;
    dirty: boolean;
    flat: boolean;
    parent: Dir | undefined;
    parentKey: string | undefined;
    unixfs: UnixFS | undefined;
    mode: number | undefined;
    mtime: import("ipfs-unixfs/dist/src/types.js").Mtime | undefined;
    /** @type {CID | undefined} */
    cid: CID | undefined;
    /** @type {number | undefined} */
    size: number | undefined;
    /**
     * @param {string} name
     * @param {DirContents} value
     */
    put(name: string, value: DirContents): Promise<void>;
    /**
     * @param {string} name
     * @returns {Promise<DirContents | undefined>}
     */
    get(name: string): Promise<DirContents | undefined>;
    /**
     * @returns {AsyncIterable<{ key: string, child: DirContents}>}
     */
    eachChildSeries(): AsyncIterable<{
        key: string;
        child: DirContents;
    }>;
    /**
     * @param {Blockstore} blockstore
     * @returns {AsyncIterable<ImportResult>}
     */
    flush(blockstore: Blockstore): AsyncIterable<ImportResult>;
}
export class DirSharded extends Dir {
    /** @type {Bucket<DirContents>} */
    _bucket: Bucket<DirContents>;
    childCount(): number;
    directChildrenCount(): number;
    onlyChild(): Bucket<DirContents> | import("hamt-sharding").BucketChild<DirContents>;
    eachChildSeries(): AsyncGenerator<{
        key: string;
        child: DirContents;
    }, void, unknown>;
}
export type ImporterOptions = import('ipfs-unixfs-importer').ImporterOptions;
export type Blockstore = import('interface-blockstore').Blockstore;
export type CID = import('multiformats/cid').CID;
export type Mtime = import('ipfs-unixfs').Mtime;
export type ImportResult = {
    cid: CID;
    node: import('@ipld/dag-pb').PBNode;
    size: number;
};
export type DirContents = {
    cid?: import("multiformats/cid").CID<any, number, number, import("multiformats/cid").Version> | undefined;
    size?: number | undefined;
};
export type DirOptions = {
    mtime?: import("ipfs-unixfs/dist/src/types.js").Mtime | undefined;
    mode?: number | undefined;
    codec?: import("multiformats/codecs/interface").BlockCodec<any, any> | undefined;
    cidVersion?: import("multiformats/cid").Version | undefined;
    onlyHash?: boolean | undefined;
    signal?: AbortSignal | undefined;
};
export type DirProps = {
    root: boolean;
    dir: boolean;
    path: string;
    dirty: boolean;
    flat: boolean;
    parent?: Dir | undefined;
    parentKey?: string | undefined;
    unixfs?: UnixFS | undefined;
    mode?: number | undefined;
    mtime?: import("ipfs-unixfs/dist/src/types.js").Mtime | undefined;
};
import { UnixFS } from "ipfs-unixfs";
import { Bucket } from "hamt-sharding";
//# sourceMappingURL=dir-sharded.d.ts.map