import { type MultiaddrInput } from '../index.js';
/**
 * A utility class to determine if a Multiaddr contains another
 * multiaddr.
 *
 * This can be used with ipcidr ranges to determine if a given
 * multiaddr is in a ipcidr range.
 *
 * @example
 *
 * ```js
 * import { multiaddr, MultiaddrFilter } from '@multiformats/multiaddr'
 *
 * const range = multiaddr('/ip4/192.168.10.10/ipcidr/24')
 * const filter = new MultiaddrFilter(range)
 *
 * const input = multiaddr('/ip4/192.168.10.2/udp/60')
 * console.info(filter.contains(input)) // true
 * ```
 */
export declare class MultiaddrFilter {
    private readonly multiaddr;
    private readonly netmask;
    constructor(input: MultiaddrInput);
    contains(input: MultiaddrInput): boolean;
}
//# sourceMappingURL=multiaddr-filter.d.ts.map